@@ -36,7 +36,9 @@ usrp1_sink_base::usrp1_sink_base (const std::string &name,
 				  int which_board,
 				  unsigned int interp_rate,
 				  int nchan,
-				  int mux
+				  int mux,
+				  const std::string fpga_filename,
+				  const std::string firmware_filename
 				  ) throw (std::runtime_error)
   : gr_sync_block (name,
 		   input_signature,
@@ -50,7 +52,10 @@ usrp1_sink_base::usrp1_sink_base (const std::string &name,
 				   interp_rate,
 				   nchan, mux,
 				   fusb_block_size,
-				   fusb_nblocks);
+				   fusb_nblocks,
+				   fpga_filename,
+				   firmware_filename
+				   );
   if (d_usrp == 0)
     throw std::runtime_error ("can't open usrp1");
 
@@ -291,6 +296,12 @@ usrp1_sink_base::set_adc_buffer_bypass (int which, bool bypass)
   return d_usrp->set_adc_buffer_bypass (which, bypass);
 }
 
+std::string
+usrp1_sink_base::serial_number()
+{
+  return d_usrp->serial_number();
+}
+
 bool
 usrp1_sink_base::_write_oe (int which_dboard, int value, int mask)
 {
