@@ -1,6 +1,6 @@
 /* -*- c++ -*- */
 /*
- * Copyright 2004 Free Software Foundation, Inc.
+ * Copyright 2004,2006 Free Software Foundation, Inc.
  * 
  * This file is part of GNU Radio
  * 
@@ -27,30 +27,38 @@
 #include <usrp1_sink_c.h>
 #include <gr_io_signature.h>
 #include <usrp_standard.h>
+#include <usrp_bytesex.h>
 
 usrp1_sink_c_sptr
 usrp1_make_sink_c (int which_board,
 		   unsigned int interp_rate,
 		   int nchan,
-		   int mux
+		   int mux,
+		   const std::string fpga_filename,
+		   const std::string firmware_filename
 		   ) throw (std::runtime_error)
 {
   return usrp1_sink_c_sptr (new usrp1_sink_c (which_board,
 					      interp_rate,
 					      nchan,
-					      mux));
+					      mux,
+					      fpga_filename,
+					      firmware_filename
+					      ));
 }
 
 
 usrp1_sink_c::usrp1_sink_c (int which_board,
 			    unsigned int interp_rate,
 			    int nchan,
-			    int mux
+			    int mux,
+			    const std::string fpga_filename,
+			    const std::string firmware_filename
 			    ) throw (std::runtime_error)
   : usrp1_sink_base ("usrp1_sink_c",
 		     gr_make_io_signature (1, 1, sizeof (gr_complex)),
-		     which_board, interp_rate,
-		     nchan, mux)
+		     which_board, interp_rate, nchan, mux,
+		     fpga_filename, firmware_filename)
 {
 }
 
@@ -81,8 +89,8 @@ usrp1_sink_c::copy_to_usrp_buffer (gr_vector_const_void_star &input_items,
 			 usrp_buffer_length / usrp_bytes_per_input_item);
 
   for (int i = 0; i < nitems; i++){
-    dst[2*i + 0] = (short) real (in[i]);	// FIXME saturate?
-    dst[2*i + 1] = (short) imag (in[i]); 	// FIXME saturate?
+    dst[2*i + 0] = host_to_usrp_short((short) real(in[i]));	// FIXME saturate?
+    dst[2*i + 1] = host_to_usrp_short((short) imag(in[i])); 	// FIXME saturate?
   }
 
   input_items_consumed = nitems;
