@@ -34,8 +34,10 @@ typedef boost::shared_ptr<usrp1_sink_c> usrp1_sink_c_sptr;
 usrp1_sink_c_sptr
 usrp1_make_sink_c (int which_board,
 		   unsigned int interp_rate,
-		   int nchan = 1,
-		   int mux = 0x98
+		   int nchan,
+		   int mux,
+		   const std::string fpga_filename,
+		   const std::string firmware_filename
 		   ) throw (std::runtime_error);
 
 
@@ -51,14 +53,18 @@ class usrp1_sink_c : public usrp1_sink_base {
   usrp1_make_sink_c (int which_board,
 		     unsigned int interp_rate,
 		     int nchan,
-		     int mux
+		     int mux,
+		     const std::string fpga_filename,
+		     const std::string firmware_filename
 		     ) throw (std::runtime_error);
 
  protected:
   usrp1_sink_c (int which_board,
 		unsigned int interp_rate,
 		int nchan,
-		int mux
+		int mux,
+		const std::string fpga_filename,
+		const std::string firmware_filename
 		) throw (std::runtime_error);
 
   virtual void copy_to_usrp_buffer (gr_vector_const_void_star &input_items,
