@@ -34,11 +34,12 @@ typedef boost::shared_ptr<usrp1_sink_s> usrp1_sink_s_sptr;
 usrp1_sink_s_sptr
 usrp1_make_sink_s (int which_board,
 		   unsigned int interp_rate,
-		   int nchan = 1,
-		   int mux = 0x98
+		   int nchan,
+		   int mux,
+		   const std::string fpga_filename,
+		   const std::string firmware_filename
 		   ) throw (std::runtime_error);
 
-
 /*!
  * \brief interface to Universal Software Radio Peripheral Tx path (Rev 1)
  *
@@ -51,14 +52,18 @@ class usrp1_sink_s : public usrp1_sink_base {
   usrp1_make_sink_s (int which_board,
 		     unsigned int interp_rate,
 		     int nchan,
-		     int mux
+		     int mux,
+		     const std::string fpga_filename,
+		     const std::string firmware_filename
 		     ) throw (std::runtime_error);
 
  protected:
   usrp1_sink_s (int which_board,
 		unsigned int interp_rate,
 		int nchan,
-		int mux
+		int mux,
+		const std::string fpga_filename,
+		const std::string firmware_filename
 		) throw (std::runtime_error);
 
   virtual void copy_to_usrp_buffer (gr_vector_const_void_star &input_items,
