@@ -41,9 +41,11 @@ class usrp1_source_base : public gr_sync_block {
 		     gr_io_signature_sptr output_signature,
 		     int which_board,
 		     unsigned int decim_rate,
-		     int nchan = 1,
-		     int mux = -1,
-		     int mode = 0
+		     int nchan,
+		     int mux,
+		     int mode,
+		     const std::string fpga_filename,
+		     const std::string firmware_filename
 		     ) throw (std::runtime_error);
 
   /*!
@@ -264,6 +266,13 @@ class usrp1_source_base : public gr_sync_block {
    */
   bool set_adc_buffer_bypass (int which, bool bypass);
 
+  /*!
+   * \brief return the usrp's serial number.
+   *
+   * \returns non-zero length string iff successful.
+   */
+  std::string serial_number();
+
   /*!
    * \brief Write direction register (output enables) for pins that go to daughterboard.
    *
